<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Elementor Blog grid widget.
 *
 * Elementor widget that displays an eye-catching headlines.
 *
 * @since 2.0.0
 */

class Blog_grid extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Blog grid widget name.
	 *
	 * @since 2.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */

	public function get_name() {
		return __( 'Blog Grid', 'luwix' );
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Blog grid widget title.
	 *
	 * @since 2.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */

	public function get_title() {
		return __( 'Blog Grid', 'luwix' );
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the blog widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since 2.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */

	public function get_categories() {
		return array( 'luwix' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve blog widget icon.
	 *
	 * @since 2.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */

	public function get_icon() {
		return 'eicon-slider-push luwix-icon';
	}

	/**
	 * Register blog widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 2.0.0
	 * @access protected
	 */

	protected function _register_controls() {

		$this->start_controls_section(
			'section',
			array(
				'label' => __( 'Genral Setting', 'luwix' ),
			)
		);

		$this->add_control(
			'blog-style',
			array(
				'label'   => __( 'blog Style', 'luwix' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'blog-style-1',
				'options' => array(
					'blog-style-1' => __( 'Style 1', 'luwix' ),
					'blog-style-2' => __( 'Style 2', 'luwix' ),
					'blog-style-3' => __( 'Style 3', 'luwix' ),
				),
			)
		);

		$this->add_responsive_control(
			'contant-word',
			array(
				'label'   => __( 'Contant Word', 'elementor' ),
				'type'    => Controls_Manager::SLIDER,
				'default' => array(
					'size' => 20,
				),
				'range'   => array(
					'px' => array(
						'min' => 0,
						'max' => 30,
					),
				),
			)
		);

		$this->add_responsive_control(
			'image_radius',
			[
				'label' => __( 'Image Radius', 'luwix' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'default' => [
					'size' => 5,
				],
				'range' => [
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .blog-style-1 .post-inner .post-image' => 'border-radius: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .blog-style-2 .post-inner .post-content' => 'border-radius: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .blog-style-3 .post-inner .post-image' => 'border-radius: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'grid_setting',
			array(
				'label'     => __( 'Grid Setting', 'luwix' ),
			)
		);

		$this->add_control(
			'total-count',
			array(
				'label'       => __( 'Total Count', 'luwix' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => '4',
			)
        );
        
        $this->add_control(
			'grid-desk',
			array(
				'label'     => __( 'Desktop view', 'luwix' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'desk-grid-4',
				'options'   => array(
					'desk-grid-2' => __( '2 Column', 'luwix' ),
					'desk-grid-3' => __( '3 Column', 'luwix' ),
					'desk-grid-4' => __( '4 Column', 'luwix' ),
					'desk-grid-5' => __( '5 Column', 'luwix' ),
				),
			)
        );
        
        $this->add_control(
			'grid-lap',
			array(
				'label'     => __( 'Laptop view', 'luwix' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'lap-grid-3',
				'options'   => array(
					'lap-grid-2' => __( '2 Column', 'luwix' ),
					'lap-grid-3' => __( '3 Column', 'luwix' ),
					'lap-grid-4' => __( '4 Column', 'luwix' ),
				),
			)
        );

        $this->add_control(
			'grid-tab',
			array(
				'label'     => __( 'Tablet view', 'luwix' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'tab-grid-3',
				'options'   => array(
					'tab-grid-2' => __( '2 Column', 'luwix' ),
					'tab-grid-3' => __( '3 Column', 'luwix' ),
					'tab-grid-4' => __( '4 Column', 'luwix' ),
				),
			)
        );
        
        $this->add_control(
			'grid-mobile',
			array(
				'label'     => __( 'Mobile view', 'luwix' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'mob-grid-2',
				'options'   => array(
                    'mob-grid-1' => __( '1 Column', 'luwix' ),
                    'mob-grid-2' => __( '2 Column', 'luwix' ),
					'mob-grid-3' => __( '3 Column', 'luwix' ),
				),
			)
        );
        
        $this->add_control(
			'grid-mobile-portal',
			array(
				'label'     => __( 'Mobile Portal view', 'luwix' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'mobpor-grid-1',
				'options'   => array(
                    'mobpor-grid-1' => __( '1 Column', 'luwix' ),
                    'mobpor-grid-2' => __( '2 Column', 'luwix' ),
				),
			)
		);
        
		$this->add_responsive_control(
			'grid-space',
			array(
				'label' => __( 'Margin', 'elementor' ),
                'type'  => Controls_Manager::SLIDER,
                'default' => [
					'size' => 25,
				],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .blog-post-main .blog-member-grid' => 'grid-gap: {{SIZE}}{{UNIT}};',
				],
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'blog_color',
			array(
				'label' => __( 'blog Color', 'luwix' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_control(
			'all-text-color',
			array(
				'label'     => __( 'Text Color', 'luwix' ),
				'type'      => Controls_Manager::COLOR,
				'condition' => array(
					'blog-style' => array('blog-style-3' ),
				),
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} .blog-member.blog-style-3 .member-info .member-name a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .blog-member.blog-style-3 .member-info .member-position' => 'color: {{VALUE}};',
					'{{WRAPPER}} .blog-member.blog-style-3 .blog-social li a' => 'color: {{VALUE}};',
				),
			)
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			array(
				'name'      => 'gradiant-s4-color',
				'label'     => __( 'Background Color', 'luwix' ),
				'condition' => array(
					'blog-style' => array( 'blog-style-3' ),
				),
				'types'     => array( 'gradient' ),
				'selector'  => '{{WRAPPER}} .blog-member.blog-style-3 .member-info:before',
			)
		);

		$this->start_controls_tabs(
			'blogs_color-tabs',
			array(
				'condition' => array(
					'blog-style' => array( 'blog-style-1', 'blog-style-2' ),
				),
			)
		);

			$this->start_controls_tab(
				'blog_color_normal',
				array(
					'label' => __( 'Normal', 'luwix' ),
				)
			);

			$this->add_control(
				'member-name',
				array(
					'label'     => __( 'Name Color', 'luwix' ),
					'type'      => Controls_Manager::COLOR,
					'default'   => '',
					'selectors' => array(
						'{{WRAPPER}} .blog-member .member-info .member-name' => 'color: {{VALUE}};',
					),
				)
			);

			$this->add_control(
				'member-position',
				array(
					'label'     => __( 'Position Color', 'luwix' ),
					'type'      => Controls_Manager::COLOR,
					'default'   => '',
					'selectors' => array(
						'{{WRAPPER}} .blog-member .member-info .member-position' => 'color: {{VALUE}};',
					),
				)
			);

			$this->add_group_control(
				Group_Control_Background::get_type(),
				array(
					'name'      => 'gradiant-bg-color',
					'label'     => __( 'Background Color', 'luwix' ),
					'condition' => array(
						'blog-style' => array( 'blog-style-1' ),
					),
					'types'     => array( 'gradient' ),
					'selector'  => '{{WRAPPER}} .blog-member.blog-style-1 .member-info',
				)
			);

			$this->end_controls_tab();

			$this->start_controls_tab(
				'blog_color_hover',
				array(
					'label' => __( 'Hover', 'luwix' ),
				)
			);

			$this->add_control(
				'member-hover-name',
				array(
					'label'     => __( 'Name Color', 'luwix' ),
					'type'      => Controls_Manager::COLOR,
					'default'   => '',
					'selectors' => array(
						'{{WRAPPER}} .blog-member .blog-member-inner:hover .member-info .member-name a' => 'color: {{VALUE}};',
					),
				)
			);

			$this->add_control(
				'member-hover-position',
				array(
					'label'     => __( 'Position Color', 'luwix' ),
					'type'      => Controls_Manager::COLOR,
					'default'   => '',
					'selectors' => array(
						'{{WRAPPER}} .blog-member .blog-member-inner:hover .member-info .member-position' => 'color: {{VALUE}};',
					),
				)
			);

			$this->add_group_control(
				Group_Control_Background::get_type(),
				array(
					'name'      => 'gradiant-hover-bg-color',
					'label'     => __( 'Background Color', 'luwix' ),
					'condition' => array(
						'blog-style' => array( 'blog-style-1' ),
					),
					'types'     => array( 'gradient' ),
					'selector'  => '{{WRAPPER}} .blog-member.blog-style-1 .blog-member-inner .member-info:before',
				)
			);

			$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->end_controls_section();

		$this->start_controls_section(
			'section_color',
			array(
				'label' => __( 'Slider Control Color', 'luwix' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'      => 'link-typography',
				'label'     => __( 'Read More Typography', 'luwix' ),
				'condition' => array(
					'blog-style' => array( 'blog-style-2'),
				),
				'selector'  => '{{WRAPPER}} .blog-member .post-inner .post-link .read-link',
			)
		);

		$this->start_controls_tabs( 'slider_arrow_style' );

		$this->start_controls_tab(
			'slider_arrow_normal',
			array(
				'label' => __( 'Normal', 'luwix' ),
			)
		);

		$this->add_control(
			'bullet_color',
			array(
				'label'     => __( 'Bullet Color', 'luwix' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} .blog-member .swiper-container .swiper-pagination-bullet' => 'background: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'arrow_color',
			array(
				'label'     => __( 'Arrow Color', 'luwix' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} .swiper-container .swiper-button-next i' => 'color: {{VALUE}};',
					'{{WRAPPER}} .swiper-container .swiper-button-prev i' => 'color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'arrow_bg_color',
			array(
				'label'     => __( 'Arrow BG Color', 'luwix' ),
				'type'      => Controls_Manager::COLOR,
				'condition' => array(
					'arrow-style' => array( 'arrow-default', 'arrow-style2' ),
				),
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} .swiper-container .swiper-button-next i' => 'background: {{VALUE}};',
					'{{WRAPPER}} .swiper-container .swiper-button-prev i' => 'background: {{VALUE}};',
				),
			)
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'slider_arrow_hover',
			array(
				'label' => __( 'Hover', 'luwix' ),
			)
		);

		$this->add_control(
			'bullet_hover_color',
			array(
				'label'     => __( 'Bullet hover Color', 'luwix' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} .blog-member .swiper-container .swiper-pagination-bullet.swiper-pagination-bullet-active' => 'background: {{VALUE}};',
					'{{WRAPPER}} .blog-member .swiper-container .swiper-pagination-bullet.swiper-pagination-bullet-active:before' => 'border-color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'arrow_hover_color',
			array(
				'label'     => __( 'Arrow Color', 'luwix' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .swiper-container .swiper-button-next:hover i' => 'color: {{VALUE}};',
					'{{WRAPPER}} .swiper-container .swiper-button-prev:hover i' => 'color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'arrow_bg_hover_color',
			array(
				'label'     => __( 'Arrow BG Color', 'luwix' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} .swiper-container .swiper-button-next:hover i' => 'background: {{VALUE}};',
					'{{WRAPPER}} .swiper-container .swiper-button-prev:hover i' => 'background: {{VALUE}};',
				),
			)
		);

		$this->end_controls_tab();

		$this->end_controls_section();

	}
	/**
	 * Render blog widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 2.0.0
	 * @access protected
	 */

	protected function render() {

		$settings = $this->get_settings();

		$args = array(
			'post_type'        => 'post',
			'post_status'      => 'publish',
			'posts_per_page'   => $settings['total-count'],
			'numberposts'      => -1,
			'suppress_filters' => 0,
		);

		$the_query = new \WP_Query( $args );

		global $post;

		$this->add_render_attribute( 'blog', 'class', 'blog-member-grid' );
		$this->add_render_attribute( 'blog', 'class', $settings['grid-desk'] );
        $this->add_render_attribute( 'blog', 'class', $settings['grid-lap'] );
        $this->add_render_attribute( 'blog', 'class', $settings['grid-tab'] );
        $this->add_render_attribute( 'blog', 'class', $settings['grid-mobile'] );
        $this->add_render_attribute( 'blog', 'class', $settings['grid-mobile-portal'] );

        $this->add_render_attribute( 'blog-class', 'class', 'blog-post-main' ); 
		$this->add_render_attribute( 'blog-class', 'class', $settings['blog-style'] );

		?>
		<div <?php echo $this->get_render_attribute_string( 'blog-class' ) ?>>
			<div <?php echo $this->get_render_attribute_string( 'blog' ); ?>>
				
				<?php

				if ( $settings['blog-style'] === 'blog-style-1' ) {
					while ( $the_query->have_posts() ) {
						$the_query->the_post();
						$blog_image = wp_get_attachment_image_src( get_post_thumbnail_id( get_the_ID() ), 'full' );
						?>
						<div class="swiper-slide">
							<div class="post-inner">
								<?php if ( has_post_thumbnail() ) { ?>
									<div class="post-image">
										<a href="#"><img class="img-fluid" src="<?php echo esc_url( $blog_image[0] ); ?>" alt=""></a>
									<?php
									$blogcat = get_the_category();
									if ( $blogcat ) {
										foreach ( $blogcat as $cat ) {
											echo '<a class="post-category" href="' . esc_url( get_category_link( $cat->cat_ID ) ) . '">' . esc_html( $cat->name ) . '</a>';
										}
									}
									?>
								</div>
								<?php } ?>
								<div class="post-content">
									<div class="post-meta">

									<div class="meta-author">
										<a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>">
											<?php echo get_avatar( get_the_author_meta( 'ID' ), 110, '', esc_attr__( 'author avatar', 'luwix' ) ); ?>
											<?php the_author(); ?>
										</a>
									</div>

									<div class="meta-date"><i class="ti ti-calendar"></i><?php echo sprintf( '%s', get_the_date() ); ?></div>
									</div>
									<div class="post-info">
									<h3 class="post-title"><a href="<?php echo esc_url( get_permalink( $the_query->ID ) ); ?>"><?php echo sprintf( '%s', esc_html__( get_the_title( $the_query->ID ), 'luwix' ) ); ?></a></h3>
									<div class="post-description">
										<?php
										$content_words = $settings['contant-word']['size'];
										$total_words   = str_word_count( get_the_content() );

										if ( $content_words > $total_words ) {
											$content_words = $total_words - 1;
										}

										if ( has_excerpt() ) {
											$excerpt_data = get_the_excerpt();

											echo wp_kses( $excerpt_data, array() );
										} else {
											$excerpt_data = get_the_content();

											$excerpt_data = strip_shortcodes( $excerpt_data );
											$excerpt_data = wp_trim_words( $excerpt_data, $content_words, '...' );
											echo wp_kses( $excerpt_data, array() );
										}
										?>
									</div>
									</div>
								</div>
							</div>
						</div>
						<?php
					}
					wp_reset_postdata();
				}
				if ( $settings['blog-style'] === 'blog-style-2' ) {
					while ( $the_query->have_posts() ) {
						$the_query->the_post();
						$blog_image = wp_get_attachment_image_src( get_post_thumbnail_id( get_the_ID() ), 'full' );
						?>
						<div class="swiper-slide">
							<div class="post-inner">
								<div class="post-content" style="background-image: url(<?php echo esc_url( $blog_image[0] ); ?>);">
									<div class="post-meta">	
										<?php
											$blogcat = get_the_category();
										if ( $blogcat ) {
											foreach ( $blogcat as $cat ) {
												echo '<a class="post-category" href="' . esc_url( get_category_link( $cat->cat_ID ) ) . '">' . esc_html( $cat->name ) . '</a>';
											}
										}
										?>
										<div class="meta-date"><i class="ti ti-calendar"></i><?php echo sprintf( '%s', get_the_date() ); ?></div>
									</div>
									<div class="post-info">
										<h3 class="post-title"><a href="<?php echo esc_url( get_permalink( $the_query->ID ) ); ?>"><?php echo sprintf( '%s', esc_html__( get_the_title( $the_query->ID ), 'luwix' ) ); ?></a></h3>
										<div class="post-description">
											<?php
											$content_words = $settings['contant-word']['size'];
											$total_words   = str_word_count( get_the_content() );

											if ( $content_words > $total_words ) {
												$content_words = $total_words - 1;
											}

											if ( has_excerpt() ) {
												$excerpt_data = get_the_excerpt();

												echo wp_kses( $excerpt_data, array() );
											} else {
												$excerpt_data = get_the_content();

												$excerpt_data = strip_shortcodes( $excerpt_data );
												$excerpt_data = wp_trim_words( $excerpt_data, $content_words, '...' );
												echo wp_kses( $excerpt_data, array() );
											}
											?>
										</div>
										<div class="post-link">
										<a class="read-link" href="<?php echo esc_url( get_permalink( $the_query->ID ) ); ?>">Read More<i aria-hidden="true" class="ion ion-ios-arrow-thin-right"></i></a>
										</div>
									</div>
								</div>
							</div>
						</div>
						<?php
					}
					wp_reset_postdata();
				}
				if ( $settings['blog-style'] === 'blog-style-3' ) {
					while ( $the_query->have_posts() ) {
						$the_query->the_post();
						$blog_image = wp_get_attachment_image_src( get_post_thumbnail_id( get_the_ID() ), 'full' );
						?>
						<div class="swiper-slide">
							<div class="post-inner">
								<?php if ( has_post_thumbnail() ) { ?>
										<div class="post-image">
											<a href="#"><img class="img-fluid" src="<?php echo esc_url( $blog_image[0] ); ?>" alt=""></a>
											<div class="meta-date"><?php echo sprintf( '%s', get_the_date( 'd' ) ); ?><span><?php echo sprintf( '%s', get_the_date( 'M' ) ); ?></span></div>
									</div>
									<?php } ?>
								<div class="post-content">
									
									<div class="post-meta">

									<?php $author_img = get_avatar( get_the_author_meta( $the_query->ID ), 20 ); ?>

										<div class="meta-author">
										<a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>">
										<i class="ti ti-user"></i><?php the_author(); ?></a>
										</div>
										<div class="meta-comments">
											<i class="ti ti-comment-alt"></i> 
											<span><?php echo luwix_get_comments_number_text(); ?></span>
										</div>
										</div>
									<div class="post-info">
									
									<h3 class="post-title"><a href="<?php echo esc_url( get_permalink( $the_query->ID ) ); ?>"><?php echo sprintf( '%s', esc_html__( get_the_title( $the_query->ID ), 'luwix' ) ); ?></a></h3>
									<div class="post-description">
										<?php
										$content_words = $settings['contant-word']['size'];
										$total_words   = str_word_count( get_the_content() );

										if ( $content_words > $total_words ) {
											$content_words = $total_words - 1;
										}

										if ( has_excerpt() ) {
											$excerpt_data = get_the_excerpt();

											echo wp_kses( $excerpt_data, array() );
										} else {
											$excerpt_data = get_the_content();

											$excerpt_data = strip_shortcodes( $excerpt_data );
											$excerpt_data = wp_trim_words( $excerpt_data, $content_words, '...' );
											echo wp_kses( $excerpt_data, array() );
										}
										?>
									</div>
									<div class="post-link">
										<a class="read-link" href="<?php echo esc_url( get_permalink( $the_query->ID ) ); ?>">Read More<i aria-hidden="true" class="ion ion-ios-arrow-thin-right"></i></a>
									</div>
								</div>
								</div>
							</div>
						</div>
						<?php
					}
					wp_reset_postdata();
				}
				?>
			</div>
		</div>

		<?php
	}

}
Plugin::instance()->widgets_manager->register_widget_type( new \Elementor\Blog_grid() );
?>
