<?php
namespace Elementor; 
if ( ! defined( 'ABSPATH' ) ) exit; 

/**
 * Elementor Blog widget.
 *
 * Elementor widget that displays an eye-catching headlines.
 *
 * @since 2.0.0
 */

class list_element extends Widget_Base {
	
	/**
	 * Get widget name.
	 *
	 * Retrieve list widget name.
	 *
	 * @since 2.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */

	public function get_name() {
		return __( 'List', 'luwix' );
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve list widget title.
	 *
	 * @since 2.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	
	public function get_title() {
		return __( 'List', 'luwix' );
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the list widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since 2.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */

	public function get_categories() {
		return [ 'luwix' ];
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve list widget icon.
	 *
	 * @since 2.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */

	public function get_icon() {
		return 'eicon-slider-push luwix-icon';
	}

	/**
	 * Register list widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 2.0.0
	 * @access protected
	 */

	protected function _register_controls() {
			
		$this->start_controls_section(
			'list-setting',
			[
				'label' => __( 'Genral Setting', 'luwix' ),
			]
		);

		$repeater = new Repeater();
        $repeater->add_control(
			'tab-title',
			[
				'label' => __( 'Title', 'luwix' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Tab Title', 'luwix' ),
				'placeholder' => __( 'Tab Title', 'luwix' ),
				'label_block' => true,
			]
        );
        
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'typography',
				'selector' => '{{WRAPPER}} .list li',
			]
		);

		$this->add_control(
			'media-type',
			[
				'label'      => __( 'List Type', 'luwix' ),
				'type'       => Controls_Manager::SELECT,
				'default'    => 'icon',
				'options'    => [
					'none'          => __( 'None', 'luwix' ),
					'list-style'    => __( 'Style Type', 'luwix' ),	
					'icon'          => __( 'Icon', 'luwix' ),			
				]
			]
		);

		$this->add_control(
			'style-type',
			[
				'label'      => __( 'List Style Type', 'luwix' ),
				'type'       => Controls_Manager::SELECT,
				'default'    => 'list-circle',
				'condition' => [
					'media-type' => 'list-style',
				],
				'options'    => [
					'list-circle'          => __( 'Circle', 'luwix' ),
					'list-square'          => __( 'Square', 'luwix' ),
					'list-disc' 		   => __( 'Disc', 'luwix' ),
					'list-decimal'         => __( 'Decimal', 'luwix' ),
					'list-decimal-zero'    => __( 'Decimal Leading Zero', 'luwix' ),
					'list-lower-alpha'     => __( 'Lower Alpha', 'luwix' ),
					'list-upper-alpha'     => __( 'Upper Alpha', 'luwix' ),
					'list-lower-roman'     => __( 'Lower Roman', 'luwix' ),				
				]
			]
		);
		
		$this->add_control(
			'icon-style',
			[
				'label'      => __( 'Icon Type', 'luwix' ),
				'type'       => Controls_Manager::SELECT,
				'default'    => 'icon-default',
				'condition' => [
					'media-type' => 'icon',
				],
				'options'    => [
					'icon-default'          => __( 'Default', 'luwix' ),
					'icon-border'          => __( 'Border', 'luwix' ),
					'icon-flat'          => __( 'Flat', 'luwix' ),			
				]
			]
		);

		$this->add_control(
			'icon-size',
			[
				'label'      => __( 'Icon Size', 'luwix' ),
				'type'       => Controls_Manager::SELECT,
				'default'    => 'size-extra-small',
				'condition' => [
					'media-type' => 'icon',
				],
				'options'    => [
					'size-extra-small'    => __( 'Extra Small', 'luwix' ),
					'size-small'          => __( 'Small', 'luwix' ),
					'size-mediam'         => __( 'Mediam', 'luwix' ),
					'size-large' 		  => __( 'Large', 'luwix' ),
					'size-extra-large' 	  => __( 'Extra Large', 'luwix' ),		
				]
			]
		);

		$this->add_control(
			'icon-shap',
			[
				'label'      => __( 'Icon Shap', 'luwix' ),
				'type'       => Controls_Manager::SELECT,
				'default'    => 'icon-square',
				'condition' => [
					'media-type' => 'icon',
					'icon-style'=>['icon-border','icon-flat']
				],
				'options'    => [
					'icon-square'          => __( 'Square', 'luwix' ),
					'icon-round'          => __( 'Round', 'luwix' ),
					'icon-rounded'          => __( 'Rounded', 'luwix' ),				
				]
			]
		);

		$this->add_responsive_control(
			'icon_space',
			[
				'label' => __( 'Icon Spacing', 'luwix' ),
				'type' => Controls_Manager::SLIDER,
				'condition' => [
					'media-type' => 'icon',
				],
				'default' => [
					'size' => 15,
				],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 50,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .list li i' => 'margin-right: {{SIZE}}{{UNIT}};',
					'.rtl {{WRAPPER}} .list li i' => 'margin-left: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'luwix-icon',
			[
				'label' => __( 'Icon', 'luwix' ),
				'type' => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'condition' => [
					'media-type' => 'icon',
				],
				'default' => [
					'value' => 'fas fa-star'
				]
			]
		);
		
		$this->add_responsive_control(
			'align',
			[
				'label' => __( 'Alignment', 'luwix' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'text-left' => [
						'title' => __( 'Left', 'luwix' ),
						'icon' => 'eicon-text-align-left',
					],
					'text-center' => [
						'title' => __( 'Center', 'luwix' ),
						'icon' => 'eicon-text-align-center',
					],
					'text-right' => [
						'title' => __( 'Right', 'luwix' ),
						'icon' => 'eicon-text-align-right',
					]
				]
			]
		);

		$this->end_controls_section(); 

		$this->start_controls_section(
			'list-items',
			[
				'label' => __( 'List Items', 'luwix' ),
			]
		);
		
		$this->add_control(
			'tabs',
			[
				'label' => __( 'Lists Items', 'luwix' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'tab-title' => __( 'List Items', 'luwix' ),  
					]
				],
			]
		);

		$this->add_responsive_control(
			'list_space',
			[
				'label' => __( 'List Spacing', 'luwix' ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'size' => 15,
				],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 50,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .list ul li' => 'padding-bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section(); 

		

		$this->start_controls_section(
			'style-list',
			[
				'label' => __( 'List Color Options', 'luwix' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'color-type',
			[
				'label'      => __( 'Select Color Type', 'luwix' ),
				'type'       => Controls_Manager::SELECT,
				'default'    => 'color-default',
				'options'    => [
					'color-default'          => __( 'Default', 'luwix' ),
					'color-custom'          => __( 'Custom', 'luwix' ),			
				]
			]
		);

		$this->add_control(
			'title-color',
			[
				'label' => __( 'Title Color', 'luwix' ),
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'color-type'=>['color-custom']
				],
				'selectors' => [
					'{{WRAPPER}} .list ul li' => 'color: {{VALUE}};',
		 		],
			]
		);

		$this->add_control(
			'icon-color',
			[
				'label' => __( 'Icon Color', 'luwix' ),
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'color-type'=>['color-custom'],
				],
				'selectors' => [
					'{{WRAPPER}} .list.color-custom.icon-default li i' => 'color: {{VALUE}};',
					'{{WRAPPER}} .list.color-custom.icon-border li i' => 'color: {{VALUE}};',
					'{{WRAPPER}} .list.color-custom.icon-flat li i' => 'color: {{VALUE}};',
		 		],
			]
		);

		$this->add_control(
			'icon-bg-color',
			[
				'label' => __( 'Icon Background Color', 'luwix' ),
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'icon-style'=>['icon-flat'],
					'color-type'=>['color-custom']
				],
				'selectors' => [
					'{{WRAPPER}} .list.color-custom.icon-flat li i' => 'background: {{VALUE}};',
		 		],
			]
		);

		$this->end_controls_section(); 

	}
	/**
	 * Render Blog widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 2.0.0
	 * @access protected
	 */
	
	protected function render() {
		
		$settings = $this->get_settings();

		$tabs = $this->get_settings_for_display( 'tabs' );  

		if($settings['media-type'] == 'icon')
		{
			$media_html = sprintf('<i aria-hidden="true" class="%1$s"></i>',esc_attr($settings['luwix-icon']['value'],'luwix'));
		}
		$align = $settings['align'];
		if($settings['media-type'] == 'icon')
		{
			$align .= sprintf(' %1$s',esc_html($settings['icon-style'],'luwix'));
			$align .= sprintf(' %1$s',esc_html($settings['icon-size'],'luwix'));
		}
		if($settings['media-type'] == 'list-style')
		{
			$align .= sprintf(' %1$s',esc_html($settings['style-type'],'luwix'));
		}

		if($settings['icon-style'] != 'icon-default') {
			$align .= sprintf(' %1$s',esc_html($settings['icon-shap'],'luwix'));
		}

		$color_type = sprintf('%1$s',esc_html($settings['color-type'],'luwix'));
		?>
		<div class="list <?php echo $color_type; ?> <?php echo esc_attr($align);?>">
			<ul>
				<?php foreach ( $tabs as $index => $item ){ ?>
					<li>
					<?php if($settings['media-type'] == 'icon') { ?>
					<?php echo $media_html; ?>
					<?php } ?>
					<span><?php echo esc_html($item['tab-title'],'luwix'); ?></span>
					</li>
				<?php } ?>
			</ul>
		</div>
		<?php	
	}	
}
Plugin::instance()->widgets_manager->register_widget_type( new \Elementor\list_element() );
?>